/**
 *
 * Magnolia Criteria API (http://www.openmindlab.com/lab/products/mgnlcriteria.html)
 * Copyright (C)2009 - 2010, Openmind S.r.l. http://www.openmindonline.it
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sourceforge.openutils.mgnlcriteria.jcr.query;

import java.util.Iterator;

import net.sourceforge.openutils.mgnlcriteria.jcr.query.xpath.impl.AbstractCriteriaImpl;
import net.sourceforge.openutils.mgnlcriteria.jcr.query.xpath.impl.AbstractMagnoliaCriteriaImpl;

import org.apache.commons.lang.StringUtils;


/**
 * @author Federico Grilli
 * @version $Id: JCRMagnoliaCriteriaQueryTranslator.java 1619 2010-01-09 14:09:02Z fgiust $
 */
public class JCRMagnoliaCriteriaQueryTranslator
{

    private final AbstractMagnoliaCriteriaImpl criteria;

    public JCRMagnoliaCriteriaQueryTranslator(final AbstractMagnoliaCriteriaImpl criteria) throws JCRQueryException
    {

        this.criteria = criteria;
    }

    public AbstractCriteriaImpl getRootCriteria()
    {
        return criteria;
    }

    public String getPredicate()
    {
        StringBuilder condition = new StringBuilder(30);
        Iterator<AbstractMagnoliaCriteriaImpl.CriterionEntry> criterionIterator = criteria.iterateExpressionEntries();

        boolean isfirst = true;
        while (criterionIterator.hasNext())
        {
            AbstractMagnoliaCriteriaImpl.CriterionEntry entry = criterionIterator.next();
            String xpathString = entry.getCriterion().toXPathString(entry.getCriteria());

            if (StringUtils.isNotBlank(xpathString))
            {
                if (!isfirst && StringUtils.isNotBlank(xpathString))
                {
                    condition.append(" and ");
                }

                condition.append(xpathString);
                isfirst = false;
            }
        }

        return condition.toString();
    }

    public String getOrderBy()
    {
        StringBuilder orderBy = new StringBuilder(30);
        Iterator<AbstractMagnoliaCriteriaImpl.OrderEntry> criterionIterator = criteria.iterateOrderings();
        while (criterionIterator.hasNext())
        {
            AbstractMagnoliaCriteriaImpl.OrderEntry oe = criterionIterator.next();
            orderBy.append(oe.getOrder().toXPathString(oe.getCriteria()));
            break;
            // ignore the rest
            /*
             * if ( criterionIterator.hasNext() ) { orderBy.append( ", " ); }
             */
        }
        return orderBy.toString();
    }
}